Module err

Module err 

Structs

Context
ContextualTranslationError
ContextualTranslationErrors
InvalidCast
NonMergeableTypes
TranslationError
TranslationErrors
UnexpectedType
WithTranslationErrors
Wrapper holding a compilation output alongside any errors that occurred.

Enums

LanguageArea
Level
Stage
TemplateParameterSpecError
Failure while loading or validating a template parameter spec (e.g. CLI --template-parameters).
TemplateSubstitutionError
Failure while substituting concrete values for ${name} template parameters.

Traits

DiagnosticSink
Trait for contexts that can accumulate errors in a diagnostic sink