pub struct Environment { /* private fields */ }Expand description
Environment for variable bindings during evaluation
Implementations
Sourceimpl Environment
impl Environment
Sourcepub fn bind(&mut self, name: SimpleIdentifier, value: Value)
pub fn bind(&mut self, name: SimpleIdentifier, value: Value)
Bind a variable to a value in this environment
Sourcepub fn lookup(&self, name: &SimpleIdentifier) -> Option<&Value>
pub fn lookup(&self, name: &SimpleIdentifier) -> Option<&Value>
Look up a variable in this environment
Sourcepub fn contains(&self, name: &SimpleIdentifier) -> bool
pub fn contains(&self, name: &SimpleIdentifier) -> bool
Check if a variable exists in this environment
Sourcepub fn bindings(&self) -> &HashMap<SimpleIdentifier, Value>
pub fn bindings(&self) -> &HashMap<SimpleIdentifier, Value>
Get all bindings
Sourcepub fn unbind(&mut self, name: &SimpleIdentifier) -> Option<Value>
pub fn unbind(&mut self, name: &SimpleIdentifier) -> Option<Value>
Remove a specific binding
Sourcepub fn merge(&mut self, other: Environment)
pub fn merge(&mut self, other: Environment)
Merge another environment into this one (other environment shadows this one)
Sourcepub fn union(self, other: Environment) -> Self
pub fn union(self, other: Environment) -> Self
Create a new environment with the union of two environments In case of conflicts, the second environment’s bindings take precedence