Module utils

Module utils 

Functions

bindings_must_have_same_type
A helper that checks if all arguments are of the same type.
doubles_poison_and
Lambda generator for computing the return type of a numeric binary operation
drop_decimal_scale
Compute the return type as the 0th argument (with its scale removed, if applicable)
must_be_same_type
A helper that checks if the given translations are of the same type.
pls_min_dec
Compute the return type as the 0th argument (with its scale removed, if applicable)
pls_min_dec_merge
Compute the merged decimal() return type for decimal + decimal or decimal - decimal.