SQLExpression

Enum SQLExpression 

pub enum SQLExpression {
Show 18 variants ArrayLiteral(ArrayLiteral), Case(Case), Cast(Cast), Dot(Dot), FunctionCallApply(FunctionCallApply), Lambda(Lambda), Leaf(Leaf), OrderByExpression(OrderByExpression), RegexpCountFunction(RegexpCountFunction), RegexpExtractFunction(RegexpExtractFunction), ExtractFunction(ExtractFunction), RowLiteral(RowLiteral), BinaryOperatorApply(BinaryOperatorApply), SQLIndexLookup(IndexLookup), UnaryOperatorApply(UnaryOperatorApply), TryCast(TryCast), WindowExpression(WindowExpression), TupleLiteral(TupleLiteral),
}

Variants



ArrayLiteral(ArrayLiteral)



Case(Case)



Cast(Cast)



Dot(Dot)



FunctionCallApply(FunctionCallApply)



Lambda(Lambda)



Leaf(Leaf)



OrderByExpression(OrderByExpression)



RegexpCountFunction(RegexpCountFunction)



RegexpExtractFunction(RegexpExtractFunction)



ExtractFunction(ExtractFunction)



RowLiteral(RowLiteral)



BinaryOperatorApply(BinaryOperatorApply)



SQLIndexLookup(IndexLookup)



UnaryOperatorApply(UnaryOperatorApply)



TryCast(TryCast)



WindowExpression(WindowExpression)



TupleLiteral(TupleLiteral)

Implementations

Source

impl SQLExpression

pub fn try_unwrap_array_literal( self, ) -> Result<ArrayLiteral, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::ArrayLiteral variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_case(self) -> Result<Case, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::Case variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_cast(self) -> Result<Cast, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::Cast variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_dot(self) -> Result<Dot, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::Dot variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_function_call_apply( self, ) -> Result<FunctionCallApply, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::FunctionCallApply variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_lambda(self) -> Result<Lambda, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::Lambda variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_leaf(self) -> Result<Leaf, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::Leaf variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_order_by_expression( self, ) -> Result<OrderByExpression, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::OrderByExpression variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_regexp_count_function( self, ) -> Result<RegexpCountFunction, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::RegexpCountFunction variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_regexp_extract_function( self, ) -> Result<RegexpExtractFunction, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::RegexpExtractFunction variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_extract_function( self, ) -> Result<ExtractFunction, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::ExtractFunction variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_row_literal(self) -> Result<RowLiteral, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::RowLiteral variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_binary_operator_apply( self, ) -> Result<BinaryOperatorApply, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::BinaryOperatorApply variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_sql_index_lookup( self, ) -> Result<IndexLookup, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::SQLIndexLookup variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_unary_operator_apply( self, ) -> Result<UnaryOperatorApply, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::UnaryOperatorApply variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_try_cast(self) -> Result<TryCast, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::TryCast variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_window_expression( self, ) -> Result<WindowExpression, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::WindowExpression variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_tuple_literal( self, ) -> Result<TupleLiteral, TryUnwrapError<Self>>

Attempts to unwrap this value to the SQLExpression::TupleLiteral variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

Source

impl SQLExpression

pub fn unwrap_array_literal(self) -> ArrayLiteral

Unwraps this value to the SQLExpression::ArrayLiteral variant. Panics if this value is of any other type.

pub fn unwrap_case(self) -> Case

Unwraps this value to the SQLExpression::Case variant. Panics if this value is of any other type.

pub fn unwrap_cast(self) -> Cast

Unwraps this value to the SQLExpression::Cast variant. Panics if this value is of any other type.

pub fn unwrap_dot(self) -> Dot

Unwraps this value to the SQLExpression::Dot variant. Panics if this value is of any other type.

pub fn unwrap_function_call_apply(self) -> FunctionCallApply

Unwraps this value to the SQLExpression::FunctionCallApply variant. Panics if this value is of any other type.

pub fn unwrap_lambda(self) -> Lambda

Unwraps this value to the SQLExpression::Lambda variant. Panics if this value is of any other type.

pub fn unwrap_leaf(self) -> Leaf

Unwraps this value to the SQLExpression::Leaf variant. Panics if this value is of any other type.

pub fn unwrap_order_by_expression(self) -> OrderByExpression

Unwraps this value to the SQLExpression::OrderByExpression variant. Panics if this value is of any other type.

pub fn unwrap_regexp_count_function(self) -> RegexpCountFunction

Unwraps this value to the SQLExpression::RegexpCountFunction variant. Panics if this value is of any other type.

pub fn unwrap_regexp_extract_function(self) -> RegexpExtractFunction

Unwraps this value to the SQLExpression::RegexpExtractFunction variant. Panics if this value is of any other type.

pub fn unwrap_extract_function(self) -> ExtractFunction

Unwraps this value to the SQLExpression::ExtractFunction variant. Panics if this value is of any other type.

pub fn unwrap_row_literal(self) -> RowLiteral

Unwraps this value to the SQLExpression::RowLiteral variant. Panics if this value is of any other type.

pub fn unwrap_binary_operator_apply(self) -> BinaryOperatorApply

Unwraps this value to the SQLExpression::BinaryOperatorApply variant. Panics if this value is of any other type.

pub fn unwrap_sql_index_lookup(self) -> IndexLookup

Unwraps this value to the SQLExpression::SQLIndexLookup variant. Panics if this value is of any other type.

pub fn unwrap_unary_operator_apply(self) -> UnaryOperatorApply

Unwraps this value to the SQLExpression::UnaryOperatorApply variant. Panics if this value is of any other type.

pub fn unwrap_try_cast(self) -> TryCast

Unwraps this value to the SQLExpression::TryCast variant. Panics if this value is of any other type.

pub fn unwrap_window_expression(self) -> WindowExpression

Unwraps this value to the SQLExpression::WindowExpression variant. Panics if this value is of any other type.

pub fn unwrap_tuple_literal(self) -> TupleLiteral

Unwraps this value to the SQLExpression::TupleLiteral variant. Panics if this value is of any other type.

Source

impl SQLExpression

pub fn get_column_references(&self) -> Vec<ColumnReference>

pub fn dot(self, rhs: Identifier) -> SQLExpression

pub fn index(self, index: SQLExpression) -> SQLExpression

pub fn cast(self, type_: SQLType) -> SQLExpression

pub fn fmt_indented(&self, f: &mut Formatter<'_>, indentation: usize) -> Result

pub fn subelements(&self) -> usize

pub fn map_leaves<F>(self, f: F) -> Self
where F: Clone + FnOnce(Leaf) -> SQLExpression,