pub struct ProjectionBuilder { /* private fields */ }Implementations
Sourceimpl ProjectionBuilder
impl ProjectionBuilder
Sourcepub fn deep_initialize_from_struct(
name: Option<Identifier>,
hst: Struct,
) -> Self
pub fn deep_initialize_from_struct( name: Option<Identifier>, hst: Struct, ) -> Self
Construct a new projection builder with items initialized to reference to the fields in the given struct. Initialize the references to the fields in this struct with the given prefix. The projection builder would be useful to be used to select the given struct by the given name.
pub fn expand_repeated_struct( array: SQLExpression, from: &Type, to: &Type, ) -> Result<SQLExpression, ExpandError>
Sourcepub fn expand(&self, to: Struct) -> Result<Self, ExpandError>
pub fn expand(&self, to: Struct) -> Result<Self, ExpandError>
Expand this projection builder to entirely cover the given type.
Where this projection builder does not define a column in the given type, it will add a null literal. It will also reorder the columns to match the given.
Arguments
to- The struct type to expand to
Sourcepub fn bind(&mut self, id: Identifier, value: SQLExpression, type_: Type)
pub fn bind(&mut self, id: Identifier, value: SQLExpression, type_: Type)
Bind a new column value in the list of projections.
Arguments
id- Bind this column. Compound identifiers are okay here. It will nest!value- Bind to this expressiontype- Assume this type. (Needed in order to construct the cast parts of a row literal.)
Sourcepub fn with_binding(
self,
id: Identifier,
value: SQLExpression,
type_: Type,
) -> Self
pub fn with_binding( self, id: Identifier, value: SQLExpression, type_: Type, ) -> Self
Bind a new column value in the list of projections, returning a new projection builder.
Arguments
id- Bind this column. Compound identifiers are okay here. It will nest!value- Bind to this expressiontype- Assume this type. (Needed in order to construct the cast parts of a row literal.)
Sourcepub fn bind_all(&self, other: &Self) -> Self
pub fn bind_all(&self, other: &Self) -> Self
Bind all projections from another projection builder to this one.
It will bind every column in the other projection builder to this one. If a column is present in both, it will be bound to the expression in the other projection builder.
Arguments
other- The other projection builder to bind the projections from with this one
Returns
The new projection builder containing the bindings from this and the other projection builder
Sourcepub fn bind_column_reference(&mut self, ident: SimpleIdentifier, type_: Type)
pub fn bind_column_reference(&mut self, ident: SimpleIdentifier, type_: Type)
Bind a new column reference in the list of projections.
Rather than binding a variable to a value, this binds a variable to a self-reference.
Arguments
ident- Bind this columntype_- Assume this type. (Needed in order to construct the cast parts of a row literal.)
Sourcepub fn initialize_key(&mut self, ident: SimpleIdentifier, struct_type: Struct)
pub fn initialize_key(&mut self, ident: SimpleIdentifier, struct_type: Struct)
Initialize a key in the list of projections from a Hamelin struct type. This will set all the expressions to self-reference column references. This is useful when wanting to construct a projection literal after having messed with the environment by removing nested elements.
Arguments
ident- Initialize this columnstruct_type- Initialize the column to a self-reference literal of this type
Sourcepub fn is_present(&self, id: &Identifier) -> bool
pub fn is_present(&self, id: &Identifier) -> bool
Test whether a key is present in the list of projections.
Returns
True if the key is present, false otherwise.
pub fn build_literal(&self) -> RowLiteral
pub fn build_sql_type(&self) -> Result<SQLRowType>
pub fn build_cast(&self) -> Result<Cast>
pub fn build_hamelin_type(self) -> Struct
pub fn build_projections(self) -> Result<Vec<Projection>>