pub enum CommandKind {
Show 24 variants
Set(SetCommand),
Where(WhereCommand),
Select(SelectCommand),
Drop(DropCommand),
Limit(LimitCommand),
Trimstrings(TrimstringsCommand),
Within(WithinCommand),
Sort(SortCommand),
From(FromCommand),
Union(UnionCommand),
Parse(ParseCommand),
Agg(AggCommand),
Distinct(DistinctCommand),
Suppress(SuppressCommand),
Window(WindowCommand),
Append(AppendCommand),
Join(JoinCommand),
Lookup(LookupCommand),
Explode(ExplodeCommand),
Unnest(UnnestCommand),
Rows(RowsCommand),
Nest(NestCommand),
Match(MatchCommand),
Error(Arc<TranslationError>),
}Variants
Set(SetCommand)
Where(WhereCommand)
Select(SelectCommand)
Drop(DropCommand)
Limit(LimitCommand)
Trimstrings(TrimstringsCommand)
Within(WithinCommand)
Sort(SortCommand)
From(FromCommand)
Union(UnionCommand)
Parse(ParseCommand)
Agg(AggCommand)
Distinct(DistinctCommand)
Suppress(SuppressCommand)
Window(WindowCommand)
Append(AppendCommand)
Join(JoinCommand)
Lookup(LookupCommand)
Explode(ExplodeCommand)
Unnest(UnnestCommand)
Rows(RowsCommand)
Nest(NestCommand)
Match(MatchCommand)
Error(Arc<TranslationError>)
Implementations
Sourceimpl CommandKind
impl CommandKind
Sourcepub fn command_class(&self) -> CommandClass
pub fn command_class(&self) -> CommandClass
Get the classification of this command
Returns CommandClass::Dml for data modification commands (APPEND),
and CommandClass::Query for all other commands.
Sourcepub fn is_source_command(&self) -> bool
pub fn is_source_command(&self) -> bool
Whether this command introduces a new data source and must appear as the first command in a pipeline (FROM, UNION, ROWS, MATCH).
Sourcepub fn has_template_parameters(&self) -> bool
pub fn has_template_parameters(&self) -> bool
Whether this command contains any template parameter references (${...})
in its expressions or table paths.
Sourcepub fn command_name(&self) -> &'static str
pub fn command_name(&self) -> &'static str
Get the display name of this command (for error messages)
Sourceimpl CommandKind
impl CommandKind
pub fn subelements(&self) -> usize
pub fn fmt_indented(&self, f: &mut Formatter<'_>, indentation: usize) -> Result