Identifier

Enum Identifier 

pub enum Identifier {
    Simple(SimpleIdentifier),
    Compound(CompoundIdentifier),
}
A pure AST identifier that is either simple or compound (no errors)

Variants

Implementations

Source

impl Identifier

pub fn try_unwrap_simple(self) -> Result<SimpleIdentifier, TryUnwrapError<Self>>

Attempts to unwrap this value to the Identifier::Simple variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

pub fn try_unwrap_compound( self, ) -> Result<CompoundIdentifier, TryUnwrapError<Self>>

Attempts to unwrap this value to the Identifier::Compound variant. Returns a [TryUnwrapError] with the original value if this value is of any other type.

Source

impl Identifier

pub fn parse(s: impl Into<String>) -> Result<Self, TranslationError>

pub fn infer_from_expression(expr: &Expression) -> Option<ParsedIdentifier>

Attempt to infer an identifier from an expression’s AST structure. Returns None if the expression doesn’t have an inferable identifier (caller should fall back to source text).

This is used during CST→AST parsing to desugar bare expressions into assignments by inferring the field name from the expression structure.

pub fn first(&self) -> SimpleIdentifier

Returns the first component of this identifier.

pub fn prefixes(&self) -> IdentifierPrefixes<'_>

Returns an iterator over all strict prefixes of this identifier. For example, x.y.z yields x, then x.y. Simple identifiers have no prefixes and return an empty iterator.

pub fn rest(&self) -> Option<Identifier>

Returns the rest of this identifier after removing the first component. Manually dispatches to the concrete type implementations.

pub fn last(&self) -> SimpleIdentifier

Returns the last component of this identifier.

pub fn has_prefix(&self, prefix: &Identifier) -> bool

Check if this identifier has the given prefix (without doing the stripping work). Returns true if prefix is a strict prefix of self. Returns false if they are equal or if prefix doesn’t match.

pub fn strip_prefix(&self, prefix: &Identifier) -> Option<Identifier>

Strip a prefix from this identifier, returning the suffix. Manually dispatches to the concrete type implementations.

pub fn segments(&self) -> &[SimpleIdentifier]

Returns a slice of SimpleIdentifier references for each segment of this identifier. For simple identifiers, returns a single-element slice. For compound identifiers, returns a slice of all parts.