pub enum ParsedSimpleIdentifier {
Valid(SimpleIdentifier),
Error(Rc<TranslationError>),
}Expand description
A parsed simple identifier that may contain an error from CST conversion
Variants
Valid(SimpleIdentifier)
Error(Rc<TranslationError>)
Implementations
Sourceimpl ParsedSimpleIdentifier
impl ParsedSimpleIdentifier
Sourcepub fn try_unwrap_valid(self) -> Result<SimpleIdentifier, TryUnwrapError<Self>>
pub fn try_unwrap_valid(self) -> Result<SimpleIdentifier, TryUnwrapError<Self>>
Attempts to unwrap this value to the ParsedSimpleIdentifier::Valid variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourcepub fn try_unwrap_error(
self,
) -> Result<Rc<TranslationError>, TryUnwrapError<Self>>
pub fn try_unwrap_error( self, ) -> Result<Rc<TranslationError>, TryUnwrapError<Self>>
Attempts to unwrap this value to the ParsedSimpleIdentifier::Error variant.
Returns a [TryUnwrapError] with the original value if this value is of any other type.
Sourceimpl ParsedSimpleIdentifier
impl ParsedSimpleIdentifier
Sourcepub fn valid_ref(&self) -> Result<&SimpleIdentifier, Rc<TranslationError>>
pub fn valid_ref(&self) -> Result<&SimpleIdentifier, Rc<TranslationError>>
Extract a reference to the valid SimpleIdentifier or return the error
Sourcepub fn valid(self) -> Result<SimpleIdentifier, Rc<TranslationError>>
pub fn valid(self) -> Result<SimpleIdentifier, Rc<TranslationError>>
Consume and extract the valid SimpleIdentifier or return the error